@@ -52,6 +52,8 @@ struct _GstDialogPrivate {
 #endif
 	GSList     *policy_widgets;
 
+	GSList     *edit_dialogs;
+
 	guint    frozen;
 	guint    modified : 1;
 };
@@ -199,6 +201,7 @@ gst_dialog_constructor (GType                  type,
 	GstDialog *dialog;
 	GstDialogPrivate *priv;
 	GtkWidget *toplevel;
+	GError *error = NULL;
 
 	object = (* G_OBJECT_CLASS (gst_dialog_parent_class)->constructor) (type,
 									    n_construct_properties,
@@ -209,8 +212,9 @@ gst_dialog_constructor (GType                  type,
 	if (priv->tool && priv->widget_name) {
 		priv->builder = gtk_builder_new ();
 
-		if (!gtk_builder_add_from_file (priv->builder, priv->tool->ui_path, NULL)) {
-			g_critical ("UI file not found: %s\n", priv->tool->ui_path);
+		if (!gtk_builder_add_from_file (priv->builder, priv->tool->ui_path, &error)) {
+			g_critical ("Error loading UI: %s", error->message);
+			g_error_free (error);
 
 			/* no point in continuing */
 			exit (-1);
@@ -635,3 +639,67 @@ gst_dialog_is_authenticated (GstDialog *dialog)
 	return TRUE;
 #endif
 }
+
+gboolean
+gst_dialog_get_editing (GstDialog *dialog)
+{
+	GstDialogPrivate *priv;
+
+	priv = GST_DIALOG_GET_PRIVATE (dialog);
+
+	return (priv->edit_dialogs != NULL);
+}
+
+void
+gst_dialog_add_edit_dialog (GstDialog *dialog,
+			    GtkWidget *edit_dialog)
+{
+	GstDialogPrivate *priv;
+
+	priv = GST_DIALOG_GET_PRIVATE (dialog);
+
+	priv->edit_dialogs = g_slist_prepend (priv->edit_dialogs, edit_dialog);
+}
+
+void
+gst_dialog_remove_edit_dialog (GstDialog *dialog,
+			       GtkWidget *edit_dialog)
+{
+	GstDialogPrivate *priv;
+
+	priv = GST_DIALOG_GET_PRIVATE (dialog);
+
+	priv->edit_dialogs = g_slist_remove (priv->edit_dialogs, edit_dialog);
+}
+
+void
+gst_dialog_stop_editing (GstDialog *dialog)
+{
+	GstDialogPrivate *priv;
+	GSList *dialogs;
+
+	priv = GST_DIALOG_GET_PRIVATE (dialog);
+
+	for (dialogs= priv->edit_dialogs; dialogs; dialogs = dialogs->next) {
+		/* hide dialogs, if they were running inside
+		 * gtk_dialog_run (), the loop will shutdown
+		 */
+		gtk_widget_hide (GTK_WIDGET (dialogs->data));
+	}
+
+	g_slist_free (priv->edit_dialogs);
+	priv->edit_dialogs = NULL;
+}
+
+void
+gst_dialog_authenticate (GstDialog *dialog)
+{
+#ifdef HAVE_POLKIT
+	GstDialogPrivate *priv;
+
+	if (!gst_dialog_is_authenticated (dialog)) {
+		priv = GST_DIALOG_GET_PRIVATE (dialog);
+		gtk_button_clicked (GTK_BUTTON (priv->polkit_button));
+	}
+#endif
+}
