@@ -84,24 +84,47 @@ privilege_search (const gchar *group)
 static void
 on_user_privilege_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
 {
-	GtkTreeModel *model = (GtkTreeModel*) data;
+	GtkTreeModel *model, *child_model;
 	GtkTreePath  *path  = gtk_tree_path_new_from_string (path_str);
-	GtkTreeIter   iter;
+	GtkTreeIter   iter, child_iter;
 	gboolean      value;
 
+	model = (GtkTreeModel*) data;
+
 	if (gtk_tree_model_get_iter (model, &iter, path)) {
-		gtk_tree_model_get (model, &iter, 0, &value, -1);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, !value, -1);
+		child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
+		gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model),
+								  &child_iter, &iter);
+
+		gtk_tree_model_get (child_model, &child_iter, COL_MEMBER, &value, -1);
+		gtk_list_store_set (GTK_LIST_STORE (child_model), &child_iter, COL_MEMBER, !value, -1);
 	}
 
 	gtk_tree_path_free (path);
 }
 
+static gboolean
+privileges_table_visible_func (GtkTreeModel *model,
+			       GtkTreeIter  *iter,
+			       gpointer      data)
+{
+	gboolean visible;
+	gchar *str;
+
+	gtk_tree_model_get (model, iter,
+			    COL_DESCRIPTION, &str,
+			    -1);
+	visible = (str != NULL);
+	g_free (str);
+
+	return visible;
+}
+
 void
 create_user_privileges_table (void)
 {
 	GtkWidget *list;
-	GtkTreeModel *model;
+	GtkTreeModel *model, *filter_model;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeIter iter;
@@ -109,9 +132,16 @@ create_user_privileges_table (void)
 	list = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
 
 	model = GTK_TREE_MODEL (gtk_list_store_new (3, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_OBJECT));
-	gtk_tree_view_set_model (GTK_TREE_VIEW (list), model);
+	filter_model = gtk_tree_model_filter_new (model, NULL);
+	gtk_tree_view_set_model (GTK_TREE_VIEW (list), filter_model);
+	g_object_unref (filter_model);
 	g_object_unref (model);
 
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), COL_DESCRIPTION, GTK_SORT_ASCENDING);
+	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (filter_model),
+						privileges_table_visible_func,
+						NULL, NULL);
+
 	column = gtk_tree_view_column_new ();
 
 	renderer = gtk_cell_renderer_toggle_new ();
@@ -120,7 +150,8 @@ create_user_privileges_table (void)
 					     renderer,
 					     "active", COL_MEMBER,
 					     NULL);
-	g_signal_connect (G_OBJECT (renderer), "toggled", G_CALLBACK (on_user_privilege_toggled), model);
+	g_signal_connect (G_OBJECT (renderer), "toggled",
+			  G_CALLBACK (on_user_privilege_toggled), filter_model);
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_end (column, renderer, TRUE);
@@ -131,7 +162,6 @@ create_user_privileges_table (void)
 
 	gtk_tree_view_column_set_sort_column_id (column, 1);
 	gtk_tree_view_insert_column (GTK_TREE_VIEW (list), column, 0);
-	gtk_tree_view_column_clicked (column);
 }
 
 void
@@ -140,28 +170,28 @@ privileges_table_add_group (OobsGroup *group, OobsListIter *list_iter)
 	const PrivilegeDescription *p;
 	GtkWidget *table;
 	GtkTreeModel *model;
+	GtkListStore *store;
 	GtkTreeIter iter;
 
 	p = privilege_search (oobs_group_get_name (group));
 
-	if (p) {
-		table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
-		model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
+	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
+	store = GTK_LIST_STORE (gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model)));
 
-		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    COL_MEMBER, FALSE,
-				    COL_DESCRIPTION, _(p->privilege),
-				    COL_GROUP, group,
-				    -1);
-	}
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    COL_MEMBER, FALSE,
+			    COL_DESCRIPTION, (p) ? _(p->privilege) : NULL,
+			    COL_GROUP, group,
+			    -1);
 }
 
 void
 privileges_table_set_from_user (OobsUser *user)
 {
 	GtkWidget *table;
-	GtkTreeModel *model;
+	GtkTreeModel *model, *child_model;
 	GtkTreeIter iter;
 	gboolean valid;
 	OobsGroup *group;
@@ -169,21 +199,21 @@ privileges_table_set_from_user (OobsUser *user)
 
 	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	valid = gtk_tree_model_get_iter_first (model, &iter);
+	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
+	valid = gtk_tree_model_get_iter_first (child_model, &iter);
 
 	while (valid) {
-		gtk_tree_model_get (model, &iter,
+		gtk_tree_model_get (child_model, &iter,
 				    COL_GROUP, &group,
 				    -1);
 
 		users = oobs_group_get_users (group);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		gtk_list_store_set (GTK_LIST_STORE (child_model), &iter,
 				    COL_MEMBER, (g_list_find (users, user) != NULL),
 				    -1);
 		g_list_free (users);
-		valid = gtk_tree_model_iter_next (model, &iter);
+		valid = gtk_tree_model_iter_next (child_model, &iter);
 	}
-	
 }
 
 static gboolean
@@ -213,25 +243,26 @@ void
 privileges_table_set_from_profile (GstUserProfile *profile)
 {
 	GtkWidget *table;
-	GtkTreeModel *model;
+	GtkTreeModel *model, *child_model;
 	GtkTreeIter iter;
 	gboolean valid;
 	OobsGroup *group;
 
 	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	valid = gtk_tree_model_get_iter_first (model, &iter);
+	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
+	valid = gtk_tree_model_get_iter_first (child_model, &iter);
 
 	while (valid) {
-		gtk_tree_model_get (model, &iter,
+		gtk_tree_model_get (child_model, &iter,
 				    COL_GROUP, &group,
 				    -1);
 
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		gtk_list_store_set (GTK_LIST_STORE (child_model), &iter,
 				    COL_MEMBER, find_group_in_profile (group, profile),
 				    -1);
 
-		valid = gtk_tree_model_iter_next (model, &iter);
+		valid = gtk_tree_model_iter_next (child_model, &iter);
 	}
 }
 
@@ -239,17 +270,18 @@ void
 privileges_table_save (OobsUser *user)
 {
 	GtkWidget *table;
-	GtkTreeModel *model;
+	GtkTreeModel *model, *child_model;
 	GtkTreeIter iter;
 	OobsGroup *group;
 	gboolean valid, member;
 
 	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
-	valid = gtk_tree_model_get_iter_first (model, &iter);
+	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
+	valid = gtk_tree_model_get_iter_first (child_model, &iter);
 
 	while (valid) {
-		gtk_tree_model_get (model, &iter,
+		gtk_tree_model_get (child_model, &iter,
 				    COL_GROUP, &group,
 				    COL_MEMBER, &member,
 				    -1);
@@ -258,6 +290,19 @@ privileges_table_save (OobsUser *user)
 		else
 			oobs_group_remove_user (group, user);
 
-		valid = gtk_tree_model_iter_next (model, &iter);
+		valid = gtk_tree_model_iter_next (child_model, &iter);
 	}
 }
+
+void
+privileges_table_clear (void)
+{
+	GtkWidget *table;
+	GtkTreeModel *model, *child_model;
+
+	table = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (table));
+	child_model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (model));
+
+	gtk_list_store_clear (GTK_LIST_STORE (child_model));
+}
