@@ -24,13 +24,22 @@
 #ifndef __PRIVILEGES_TABLE_H
 #define __PRIVILEGES_TABLE_H
 
+#include "user-profiles.h"
+
 void     create_user_privileges_table      (void);
 void     create_profile_privileges_table   (void);
+void     privileges_table_clear            (void);
 
 void     populate_privileges_table         (GtkWidget*, gchar*);
-void     populate_privileges_table_from_profile (GtkWidget*, xmlNodePtr);
-
 GList*   user_privileges_get_list          (GList*);
 
+void     privileges_table_add_group        (OobsGroup    *group,
+                                            OobsListIter *list_iter);
+
+void     privileges_table_set_from_profile (GstUserProfile *profile);
+void     privileges_table_set_from_user    (OobsUser *user);
+
+void     privileges_table_save             (OobsUser *user);
+
 
 #endif /* __PRIVILEGES_TABLE_H */
